@@ -87,7 +87,9 @@ dplyr::filter
 #' @export
 #' @importFrom dplyr distinct
 distinct.panel_data <- function(.data, ..., .keep_all = FALSE) {
-  reconstruct(NextMethod(), .data)
+  out <- tibble::as_tibble(.data)
+  out <- dplyr::distinct(out, ..., .keep_all = .keep_all)
+  reconstruct(out, .data)
 }
 
 #' @export
@@ -193,4 +195,22 @@ summarize_.panel_data <- function(.data, ..., .dots = list()) {
 #'
 slice_.panel_data <- function(.data, ..., .dots = list()) {
   reconstruct(NextMethod(), .data)
-}
\ No newline at end of file
+}
+
+##### tidyr ##################################################################
+
+#' @export
+#' @importFrom tidyr nest
+nest.panel_data <- function(.data, ...) {
+  out <- tibble::as_tibble(.data)
+  
+  groups <- dplyr::groups(.data)
+  if (length(groups) != 0L) {
+    out <- dplyr::group_by(out, !!!groups)
+  }
+  
+  out <- tidyr::nest(out, ...)
+  
+  reconstruct(out, .data)
+}
+
